@@ -9,7 +9,8 @@ TRANSACTION_FEE_RATE: float = float(os.getenv('BSVLIB_TRANSACTION_FEE_RATE') or
 P2PKH_DUST_LIMIT: int = int(os.getenv('BSVLIB_P2PKH_DUST_LIMIT') or 135)
 HTTP_REQUEST_TIMEOUT: int = int(os.getenv('BSVLIB_HTTP_REQUEST_TIMEOUT') or 30)
 THREAD_POOL_MAX_EXECUTORS: int = int(os.getenv('BSVLIB_THREAD_POOL_MAX_EXECUTORS') or 10)
-BIP39_ENTROPY_DEFAULT_BIT_LENGTH: int = int(os.getenv('BSVLIB_BIP39_ENTROPY_DEFAULT_BIT_LENGTH') or 128)
+BIP39_ENTROPY_BIT_LENGTH: int = int(os.getenv('BSVLIB_BIP39_ENTROPY_BIT_LENGTH') or 128)
+BIP44_DERIVATION_PATH = os.getenv('BSVLIB_BIP44_DERIVATION_PATH') or "m/44'/236'/0'"
 METASV_TOKEN: Optional[str] = os.getenv('BSVLIB_METASV_TOKEN') or os.getenv('METASV_TOKEN')
 
 
