@@ -1,5 +1,4 @@
 import json
-from contextlib import suppress
 from typing import List, Dict, Optional
 
 import requests
@@ -8,17 +7,14 @@ from .provider import Provider, BroadcastResult
 from ..constants import Chain
 
 
-class WhatsOnChain(Provider):
+class WhatsOnChain(Provider):  # pragma: no cover
 
     def __init__(self, chain: Chain = Chain.MAIN, headers: Optional[Dict] = None, timeout: Optional[int] = None):
         super().__init__(chain, headers, timeout)
         self.url: str = 'https://api.whatsonchain.com/v1/bsv'
 
     def get_unspents(self, **kwargs) -> List[Dict]:
-        """
-        only P2PKH unspents
-        """
-        with suppress(Exception):
+        try:
             address, _, _ = self.parse_kwargs(**kwargs)
             r: Dict = self.get(url=f'{self.url}/{self.chain}/address/{address}/unspent')
             unspents: List[Dict] = []
@@ -27,16 +23,22 @@ class WhatsOnChain(Provider):
                 unspent.update(kwargs)
                 unspents.append(unspent)
             return unspents
-        return []  # pragma: no cover
+        except Exception as e:
+            if kwargs.get('throw'):
+                raise e
+        return []
 
     def get_balance(self, **kwargs) -> int:
-        with suppress(Exception):
+        try:
             address, _, _ = self.parse_kwargs(**kwargs)
             r: Dict = self.get(url=f'{self.url}/{self.chain}/address/{address}/balance')
             return r.get('confirmed') + r.get('unconfirmed')
-        return 0  # pragma: no cover
+        except Exception as e:
+            if kwargs.get('throw'):
+                raise e
+        return 0
 
-    def broadcast(self, raw: str) -> BroadcastResult:  # pragma: no cover
+    def broadcast(self, raw: str) -> BroadcastResult:
         propagated, message = False, ''
         try:
             data = json.dumps({'txHex': raw})
