@@ -85,6 +85,9 @@ class TxInput:
     def __str__(self) -> str:  # pragma: no cover
         return f'<TxInput outpoint={self.txid}:{self.vout} satoshi={self.satoshi} locking_script={self.locking_script}>'
 
+    def __repr__(self) -> str:  # pragma: no cover
+        return self.__str__()
+
     @classmethod
     def from_hex(cls, stream: Union[str, bytes, TransactionBytesIO]) -> Optional['TxInput']:
         with suppress(Exception):
@@ -104,12 +107,9 @@ class TxInput:
 
 class TxOutput:
 
-    def __init__(self, out: Union[str, List[Union[str, bytes]], Script, None] = None, satoshi: int = 0, script_type: ScriptType = UnknownScriptType()):
+    def __init__(self, out: Union[str, List[Union[str, bytes]], Script], satoshi: int = 0, script_type: ScriptType = UnknownScriptType()):
         self.satoshi = satoshi
-        if out is None:
-            self.locking_script: Script = Script()
-            self.script_type: ScriptType = UnknownScriptType()
-        elif isinstance(out, str):
+        if isinstance(out, str):
             # from address
             self.locking_script: Script = P2pkhScriptType.locking(out)
             self.script_type: ScriptType = P2pkhScriptType()
@@ -130,6 +130,9 @@ class TxOutput:
     def __str__(self) -> str:  # pragma: no cover
         return f'<TxOutput satoshi={self.satoshi} locking_script={self.locking_script.hex()}>'
 
+    def __repr__(self) -> str:  # pragma: no cover
+        return self.__str__()
+
     @classmethod
     def from_hex(cls, stream: Union[str, bytes, TransactionBytesIO]) -> Optional['TxOutput']:
         with suppress(Exception):
@@ -320,6 +323,7 @@ class Transaction:
     def estimated_byte_length(self, **kwargs) -> int:
         """
         :returns: estimated byte length of this transaction after signing
+        if transaction has already signed, it will return the same value as function byte_length
         """
         estimated_length = 4 + len(unsigned_to_varint(len(self.tx_inputs))) + len(unsigned_to_varint(len(self.tx_outputs))) + 4
         for tx_input in self.tx_inputs:
@@ -361,9 +365,9 @@ class Transaction:
             self.add_output(change_output)
         return self
 
-    def broadcast(self) -> BroadcastResult:  # pragma: no cover
-        fee_expected = math.ceil(self.fee_rate * self.byte_length())
-        if self.fee() < fee_expected:
+    def broadcast(self, check_fee: bool = True) -> BroadcastResult:  # pragma: no cover
+        fee_expected = self.estimated_fee()
+        if check_fee and self.fee() < fee_expected:
             raise InsufficientFunds(f'require {self.satoshi_total_out() + fee_expected} satoshi but only {self.satoshi_total_in()}')
         return Service(self.chain, self.provider).broadcast(self.hex())
 
